@@ -1,10 +1,10 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 set.seed(1234)
 library(INLA)
-if (file.exists("myinit.R")) source("myinit.R")
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
 inla.setOption(inla.mode="classic")
+if (file.exists("myinit.R")) source("myinit.R")
 library(ggplot2)
 library(sn)
 library(knitr)
@@ -23,6 +23,15 @@ opts_chunk$set(size='small'
                , results='hold'
                , eval=TRUE)
 
+## ----eval=F-------------------------------------------------------------------
+#  inla.setOption(inla.mode="classic")
+
+## ----eval=F-------------------------------------------------------------------
+#  inla.setOption(inla.mode="experimental")
+
+## -----------------------------------------------------------------------------
+inla.getOption('inla.mode')
+
 ## -----------------------------------------------------------------------------
 n = 100
 x = rnorm(n, mean = 1, sd = 0.3)
